# ----------
setwd("C:/Users/pychen/OneDrive - Delft University of Technology/Desktop/PhD/Second study/Data analysis")


#library(purrr)
#library(lme4)
library(ggplot2)
library(tidyr) 
library(Rmisc)
library(dplyr)
#library(lmerTest)
#library(ggmosaic)
#library(viridis)
#library(ggalluvial)
#library(Hmisc)
#library(car)

rawdat_1 <- read.csv("part_1.csv")
rawdat_2 <- read.csv("part_2.csv")
rawdat_4 <- read.csv("part_4.csv")
dat_5 <- read.csv("scenario_coded_all.csv")

dat_open <- read.csv("open.csv")
names(dat_open)[1] <- "ID"
dat_free <- read.csv("guided_free.csv")
names(dat_free)[1] <- "ID"
dat_mc <- read.csv("guided_MC.csv")
names(dat_mc)[1] <- "ID"

### pre processing dat 1----------
# drop the first two raws (double colname)
dat_1 <- rawdat_1[-(1:2),]
# select columns
dat_1 <- dat_1 %>% select(contains('Q'))
# delete first column which is consent
dat_1 <- dat_1[, -1]

# Rename the first n columns
new_column_names <- c("ID","Gender","Age","Education","STEM","Programming")
names(dat_1)[1:6] <- new_column_names

# Strings and corresponding numeric values for recoding
recode_mapping_likely <- c("Extremely unlikely" = 1, 
                           "Somewhat unlikely" = 2, 
                           "Neither likely nor unlikely" = 3,
                           "Somewhat likely" = 4,
                           "Extremely likely" = 5)
# Mutate only columns where recoding is applicable
dat_1 <- dat_1 %>%
  dplyr::mutate(across(starts_with('Q'), ~recode(., !!!recode_mapping_likely,.default = NA_real_)))

# mean
shame_proneness <- c("Q2_2", "Q3_2", "Q4_5", "Q5_2", "Q6_3", "Q7_3", "Q8_1", "Q9_1",
                     "Q10_2", "Q11_4", "Q12_2", "Q24_2", "Q25_3", "Q26_1", "Q27_1", "Q28_4")
guilt_proneness <- c("Q2_4", "Q3_1", "Q4_1", "Q5_4", "Q6_5", "Q7_2", "Q8_5", "Q9_3",
                     "Q10_5", "Q11_3", "Q12_5", "Q24_5", "Q25_4", "Q26_4", "Q27_4", "Q28_2")
hu_pride_proneness <- c("Q4_2", "Q7_1", "Q9_4", "Q12_4")
au_pride_proneness <- c("Q4_3", "Q7_4", "Q9_5", "Q12_3", "Q26_5")

dat_1 <- dat_1 %>% 
  dplyr::mutate(shame_proneness = rowMeans(across(all_of(shame_proneness))),
         guilt_proneness = rowMeans(across(all_of(guilt_proneness))),
         au_pride_proneness = rowMeans(across(all_of(au_pride_proneness))),
         hu_pride_proneness = rowMeans(across(all_of(hu_pride_proneness))))
# Create dat with selected columns
dat_1 <- dat_1 %>%
  select(ID,Gender,Age,Education,STEM,Programming,
         shame_proneness,guilt_proneness,au_pride_proneness,hu_pride_proneness)

### pre processing dat 2----------
# drop the first two raws (double colname)
dat_2 <- rawdat_2[-(1:2),]
# select columns
dat_2 <- dat_2 %>% select(c("Q4_1","Q4_2","PROLIFIC_PID","Condition"))
# Rename the first n columns
new_column_names <- c("Motivated","Realistic","ID","Condition")
names(dat_2) <- new_column_names

# Strings and corresponding numeric values for recoding
recode_mapping_extreme <- c("Not at all" = 1, 
                           "Slightly" = 2, 
                           "Moderately" = 3,
                           "Very" = 4,
                           "Extremely" = 5)
# Mutate only columns where recoding is applicable
dat_2 <- dat_2 %>%
  dplyr::mutate(across(matches("Motivated|Realistic"),
            ~ recode(., !!!recode_mapping_extreme,.default = NA_real_)))

### pre processing dat 4----------
# drop the first two raws (double colname)
dat_4 <- rawdat_4[-(1:2),]
# select columns
dat_4 <- dat_4 %>% select(contains(c('ExternalReference','Condition', 'Q')))
# drop the last column (feedback Q)
dat_4 <- dat_4 [1: ncol(dat_4)-1 ]
# rename
names(dat_4)[1] <- "ID"
names(dat_5)[1] <- "ID"


### emotion data in dat_4----------
# select emotion columns ----
dat_4_emo <- dat_4 %>% select(contains(c('ID','Condition', 'Q40')))

# revalue
recode_mapping_emo <- c("Strongly disagree" = 1, 
                        "Somewhat disagree" = 2, 
                        "Neither agree nor disagree" = 3,
                        "Somewhat agree" = 4,
                        "Strongly agree" = 5)
dat_4_emo <- dat_4_emo %>% 
  dplyr::mutate(across(starts_with('Q40'), 
                ~ recode(., !!!recode_mapping_emo,.default = NA_real_)))

#sum values 
dat_4_emo <- dat_4_emo %>% 
  dplyr::mutate(shame = rowMeans(across(c(Q40_1, Q40_5, Q40_9, Q40_13))),
         guilt = rowMeans(across(c(Q40_2, Q40_6, Q40_10, Q40_14))),
         au_pride = rowMeans(across(c(Q40_3, Q40_7, Q40_11, Q40_15))),
         hu_pride = rowMeans(across(c(Q40_4, Q40_8, Q40_12, Q40_16))))

# select and recode deq columns ----
dat_4_deq <- dat_4 %>% select(ID,Condition,
                              Q18, Q20, Q21, Q22, Q23, Q24, Q25)
dat_4_deq <- dat_4_deq %>%
  dplyr::mutate(across(c(Q18, Q20, Q21, Q23, Q24), 
                ~ recode(., 
                         "Strongly disagree" = 1, 
                         "Disagree" = 2, 
                         "Somewhat disagree" = 3,
                         "Neither agree nor disagree" = 4,
                         "Somewhat agree" = 5,
                         "Agree" = 6,
                         "Strongly agree" = 7,.default = NA_real_)))

# Reverse mapping 
dat_4_deq <- dat_4_deq %>%
  dplyr::mutate(across(c(Q22, Q25), 
                ~ recode(., 
                         "Strongly agree" = 1,
                         "Agree" = 2,
                         "Somewhat agree" = 3,
                         "Neither agree nor disagree" = 4,
                         "Somewhat disagree" = 5,
                         "Disagree" = 6,
                         "Strongly disagree" = 7,.default = NA_real_)))
#sum values 
dat_4_deq <- dat_4_deq %>% 
  dplyr::mutate(deq = rowMeans(across(c(Q18, Q20, Q21, Q23, Q24, Q22, Q25))))


# merge with selected columns ----------
# List of column names to be merged
selected_emo_col <- c("shame","guilt","au_pride","hu_pride")
# Left join selected columns based on "ID" column
dat_4 <- dat_4 %>%
  left_join(select(dat_4_emo, ID, all_of(selected_emo_col)), by = "ID")
# List of column names to be merged 
selected_deq_col <- c("deq")
# Left join selected columns based on "ID" column
dat_4 <- dat_4 %>%
  left_join(select(dat_4_deq, ID, all_of(selected_deq_col)), by = "ID")
dat_4 <- dat_4 %>%
  left_join(select(dat_5, ID, Category), by = "ID")

# select final col--------
dat_4 <- dat_4 %>% select(ID, Condition,Category,shame,guilt,
                          au_pride,hu_pride,deq)

# Join df
df1_selected <- dat_open %>% select(ID, Accuracy, Comprehensive)
df2_selected <- dat_free %>% select(ID, Accuracy, Comprehensive)
df3_selected <- dat_mc %>% select(ID, Accuracy, Comprehensive)

# Combine the selected dataframes 
acc_df <- bind_rows(df1_selected, df2_selected, df3_selected)

# Merge all dat to dat_all
dat_all <- dat_1 %>% left_join(dat_2, by = "ID", relationship = "many-to-many")
dat_all <- dat_all %>% left_join(dat_4, by = c("ID"="ID", "Condition"="Condition"), relationship = "many-to-many")
dat_all <- dat_all %>% left_join(acc_df, by = "ID", relationship = "many-to-many")
dat_all <- na.omit(dat_all)
############# all data preparation done ########## ----------


########### control variables check ###################

### different emo proneness ~ condition? ###
dat_emo_proneness <- dat_all %>% select(ID,Condition,shame_proneness,guilt_proneness,au_pride_proneness,hu_pride_proneness)
dat_emo_proneness_long <- dat_emo_proneness %>%
  pivot_longer(cols = c(shame_proneness,guilt_proneness,au_pride_proneness,hu_pride_proneness),
               names_to = "measure",
               values_to = "score")
dat_emo_proneness.summary <- summarySE(dat_emo_proneness_long, measurevar="score", groupvars=c("Condition","measure"))
ggplot(dat_emo_proneness.summary, aes(x=measure,y=score,colour = Condition, group = Condition)) +
  geom_errorbar(aes(ymin=score-se, ymax=score+se), width=.2) +
  geom_line() +
  theme_bw() +
  geom_point(size = 5)

### Different STEM, Gender, Age, Education, Category ~ condition? ###
dat_demographics <- dat_all %>% select(ID,Condition,Category,Gender,Age,Education,STEM,Programming)

# Create individual plots for each variable by Condition
plot_stem <- ggplot(dat_demographics, aes(x = Condition, fill = STEM)) +
  geom_bar(position = "fill") +
  labs(title = "Distribution of STEM by Condition") +
  theme_minimal()

plot_gender <- ggplot(dat_demographics, aes(x = Condition, fill = Gender)) +
  geom_bar(position = "fill") +
  labs(title = "Distribution of Gender by Condition") +
  theme_minimal()

plot_age <- ggplot(dat_demographics, aes(x = Condition, fill = Age)) +
  geom_bar(position = "fill") +
  labs(title = "Distribution of Age by Condition") +
  theme_minimal()

plot_education <- ggplot(dat_demographics, aes(x = Condition, fill = Education)) +
  geom_bar(position = "fill") +
  labs(title = "Distribution of Education by Condition") +
  theme_minimal()

plot_programming <- ggplot(dat_demographics, aes(x = Condition, fill = Programming)) +
  geom_bar(position = "fill") +
  labs(title = "Distribution of Programming by Condition") +
  theme_minimal()

plot_category <- ggplot(dat_demographics, aes(x = Condition, fill = Category)) +
  geom_bar(position = "fill") +
  labs(title = "Distribution of Category by Condition") +
  theme_minimal()

# Combine the plots into a 2x2 grid
library(gridExtra)
grid.arrange(plot_stem, plot_gender, plot_age, plot_education, plot_programming, plot_category, ncol = 2)

# stats test
chisq.test(table(dat_demographics$Condition, dat_demographics$STEM)) #ok
chisq.test(table(dat_demographics$Condition, dat_demographics$Gender)) #ok
chisq.test(table(dat_demographics$Condition, dat_demographics$Age)) #ok
chisq.test(table(dat_demographics$Condition, dat_demographics$Education)) #ok
chisq.test(table(dat_demographics$Condition, dat_demographics$Programming)) #ok
chisq.test(table(dat_demographics$Condition, dat_demographics$Category)) #ok


# different motivation/realistic ~ condition?
dat_mot <- dat_all %>% select(ID,Condition,Motivated,Realistic)
dat_mot_long <- dat_mot %>%
  pivot_longer(cols = c(Motivated,Realistic),
               names_to = "measure",
               values_to = "score")
dat_mot.summary <- summarySE(dat_mot_long, measurevar="score", groupvars=c("Condition","measure"))
ggplot(dat_mot.summary, aes(x=measure,y=score,colour = Condition, group = Condition)) +
  geom_errorbar(aes(ymin=score-se, ymax=score+se), width=.2) +
  geom_line() +
  theme_bw() +
  geom_point(size = 5)



################# regression analysis ----------------------
########### Emotions ###################
dat_emo <- dat_all %>% select(ID,Condition,Category,guilt,shame,au_pride,hu_pride,
                              guilt_proneness,shame_proneness,
                              au_pride_proneness,hu_pride_proneness,
                              Motivated,Realistic,
                              Programming,STEM)
#guilt
guilt_mod <- lm(guilt ~ shame_proneness, data = dat_emo)
par(mfrow = c(2, 2))
plot(guilt_mod)
summary(guilt_mod)

#shame
shame_mod <- lm(shame ~ shame_proneness, data = dat_emo)
par(mfrow = c(2, 2))
plot(shame_mod)
summary(shame_mod)
#authentic pride 
au_pride_mod <- lm(au_pride ~ Condition+Motivated, data = dat_emo)
par(mfrow = c(2, 2))
plot(au_pride_mod)
summary(au_pride_mod)

#hubristic pride
hu_pride_mod <- lm(hu_pride ~ Motivated, data = dat_emo)
par(mfrow = c(2, 2))
plot(hu_pride_mod)
summary(hu_pride_mod)

# Relevel the factor
dat_emo$Condition <- relevel(dat_emo$Condition, ref = "Guided MC")
# Rerun the linear model
lm_2 <- lm(au_pride ~ Condition + Motivated, data = dat_emo)
summary(lm_2)

########### au_pride & DEQ ###################
dat_pride_deq <- dat_all %>% select(ID,Condition,guilt,shame,au_pride,hu_pride,
                                    guilt_proneness,shame_proneness,
                                    au_pride_proneness,hu_pride_proneness,
                                    deq)
pride_deq_mod <- lm(deq ~ au_pride, data = dat_pride_deq)
summary(pride_deq_mod)
########### User satisfication ###################

dat_exp <- dat_all %>% select(ID,Condition,Category,
                              Accuracy,Comprehensive,deq,
                                    Motivated,Realistic,
                                    Programming,STEM,Education)

#Accuracy 
acc_mod <- lm(Accuracy ~ Realistic, data = dat_exp)
par(mfrow = c(2, 2))
plot(acc_mod)
summary(acc_mod)
#Comprehensive # no interaction
comp_mod <- lm(Comprehensive ~ Condition+Motivated, data = dat_exp)
par(mfrow = c(2, 2))
plot(acc_mod)
summary(comp_mod)
#DEQ
# Filter the data to remove the "Prefer not to say" level
dat_exp_filtered <- dat_exp %>%
  filter(Education != "Prefer not to say")

# Recode the Education variable into two groups
dat_exp_filtered$Education_simple <- ifelse(dat_exp_filtered$Education == "High school graduate", "High school", "Bachelor and above")
mod_1 <- lm(deq ~ Condition*Education_simple + Realistic + Motivated, data = dat_exp_filtered)
mod_2 <- lm(deq ~ Condition + Realistic + Motivated, data = dat_exp_filtered)
anova(mod_1,mod_2)
summary(mod_1)

par(mfrow = c(2, 2))
plot(mod_2)


############## PLOTS for the paper ####################

### deq interaction plot ###
# Calculate the mean and standard error of deq for each Condition*Education combination
mean_deq <- dat_exp_filtered %>%
  group_by(Condition, Education_simple) %>%
  summarize(mean_deq = mean(deq),
            se_deq = sd(deq) / sqrt(n()))  # Standard error

# Define the mapping for condition names
condition_name_map <- c(
  Open = "Exploratory",
  `Guided free` = "Focused",
  `Guided MC` = "Structured Choice"
)

# Apply the name mapping to the Condition column in your data
mean_deq$Condition <- as.character(mean_deq$Condition)  # Convert to character to avoid factor issues
mean_deq$Condition <- condition_name_map[mean_deq$Condition]

# Reorder the factor levels for Education_simple
mean_deq$Education_simple <- factor(mean_deq$Education_simple, levels = c("High school", "Bachelor and above"))

interaction_plot <- ggplot(mean_deq, aes(x = Education_simple, y = mean_deq, group = Condition, color = Condition)) +
  geom_line() +
  geom_point(aes(shape = Condition, fill = Condition), size = 4) +
  scale_shape_manual(values=c(21, 22, 23), labels=c("Exploratory", "Focused", "Structured Choice")) +
  scale_color_manual(values = c("#d192b4", "#80ac54","#0072B2"), labels=c("Exploratory", "Focused", "Structured Choice")) +
  scale_fill_manual(values = c("#d192b4", "#80ac54","#0072B2"), labels=c("Exploratory", "Focused", "Structured Choice")) +
  geom_errorbar(aes(ymin = mean_deq - se_deq, ymax = mean_deq + se_deq), width = 0.04) +
  labs(
    x = "Educational levels",  # X-axis label
    y = "Dialogue Experience Questionnaire\n(mean & standard error)",  # Y-axis label
    color = "Dialogue strategy",
    shape = "Dialogue strategy",
    fill = "Dialogue strategy") +
  ylim(3.8, 4.75) +
  theme_minimal() +
  theme(
    legend.position = "bottom",
    legend.key.size = unit(0.5, 'cm'),  # Smaller legend keys
    legend.text = element_text(size = 8),  # Smaller text in the legend
    legend.title = element_text(size = 9),  # Smaller legend title
    panel.border = element_rect(color = "black", fill = NA, linewidth = 0.5),  # Adds the rectangle border
    panel.background = element_blank(),
    panel.grid.major = element_line(color = "grey90", linewidth = 0.5),  # Adds horizontal grid lines
    panel.grid.minor = element_blank(),  # Removes minor grid lines if not needed
    panel.grid.major.x = element_blank(),  # Removes vertical grid lines
    axis.line = element_line(color = "black", linewidth = 0.5),  # Adds axis lines
    axis.text.x = element_text(size = 8),  # Change x axis text size
    axis.text.y = element_text(size = 8),  # Change y axis text size
    axis.title.x = element_text(size = 9), # Change x axis title size
    axis.title.y = element_text(size = 9)  # Change y axis title size
  ) +
  guides(
    color = guide_legend(direction = "horizontal"), 
    shape = guide_legend(),
    fill = guide_legend(direction = "horizontal"))

# Display the line plot
print(interaction_plot)
ggsave("interaction_plot.png", plot = interaction_plot, width = 6, height = 3, dpi = 300)



### plot with 4 emotion subplot ###
dat_emo <- dat_all %>% select(ID,Condition,guilt,shame,au_pride,hu_pride,
                              guilt_proneness,shame_proneness,
                              au_pride_proneness,hu_pride_proneness,
                              Motivated,Realistic,
                              Programming,STEM)

# Named vector to map old names to new ones
emotion_name_map  <- c(
  shame = "Shame",
  guilt = "Guilt",
  au_pride = "Authentic Pride",
  hu_pride = "Hubristic Pride"
)

condition_name_map <- c(
  Open = "Exploratory",
  `Guided free` = "Focused",
  `Guided MC` = "Structured Choice"
)

# Create a boxplot for each emotion, faceted by emotion
dat_emo_multi_long <- dat_emo %>%
  pivot_longer(cols = c(shame, guilt, au_pride, hu_pride),
               names_to = "emotion",
               values_to = "value") %>%
  # Use the mappings to rename emotions and conditions
  mutate(emotion = emotion_name_map[emotion],
         Condition = condition_name_map[Condition]) %>%
  # Set the factor level orders for 'emotion' and 'Condition'
  mutate(emotion = factor(emotion, levels = c("Shame", "Guilt", "Authentic Pride", "Hubristic Pride")),
         Condition = factor(Condition, levels = c("Exploratory", "Focused", "Structured Choice")))


# Calculate mean and standard error (SE) for each emotion by Condition
emotion_summary <- dat_emo_multi_long %>%
  group_by(emotion, Condition) %>%
  summarize(
    Mean = mean(value),
    SE = sd(value) / sqrt(n())
  )



# Create a line plot with error bars for each emotion, faceted by emotion
# Determine the common y-axis limits for all subplots
#y_limits <- range(emotion_summary$Mean - emotion_summary$SE, emotion_summary$Mean + emotion_summary$SE)
#y_limits <- range(2.2,3.25)
y_coord_star_1 <- 3.04
y_coord_star_2 <- 3.12
line_plot_emotions <- ggplot(emotion_summary, aes(x = Condition, y = Mean, group = emotion)) +
  geom_errorbar(aes(ymin = Mean - SE, ymax = Mean + SE, color = Condition), width = 0.2) +  # Color error bars by Condition
  geom_point(aes(color = Condition), size = 3) +  # Add points with color by Condition
  labs(
    #title = "Line Plot of Emotions by Condition with Error Bars",
    #x = "Dialogue strategy",
    y = "Mean and standard error",
  ) +
  scale_color_manual(values = c("#d192b4", "#80ac54","#0072B2"), labels=c("Exploratory", "Focused", "Structured Choice")) +
  scale_fill_manual(values = c("#d192b4", "#80ac54","#0072B2"), labels=c("Exploratory", "Focused", "Structured Choice")) +
  facet_wrap(~emotion, ncol = 2) +  # Facet by emotion
  #scale_y_continuous(limits = y_limits) +
  geom_text(
    aes(x = 1.5, y = y_coord_star_1, label = "*"),
    data = subset(emotion_summary, emotion == "Authentic Pride"),
    color = "black",
    size = 4
  ) +
  geom_segment(data = subset(emotion_summary, emotion == "Authentic Pride"),
               aes(x = 1, xend = 2, y = y_coord_star_1, yend = y_coord_star_1), color = "black", size = 0.3) +  # Manually add the red vertical line
  geom_text(
    aes(x = 2, y = y_coord_star_2, label = "*"),
    data = subset(emotion_summary, emotion == "Authentic Pride"),
    color = "black",
    size = 4
  ) +
  geom_segment(data = subset(emotion_summary, emotion == "Authentic Pride"),
               aes(x = 1, xend = 3, y = y_coord_star_2, yend = y_coord_star_2), color = "black", size = 0.3) +  # Manually add the red vertical line
  theme_minimal() +
  theme(
    legend.position = "bottom",
    legend.margin = margin(t = -10, b = 0, unit = "pt"),  # Reduce top margin to move legend closer
    legend.key.size = unit(0.5, 'cm'),  # Smaller legend keys
    legend.text = element_text(size = 8),  # Smaller text in the legend
    legend.title = element_text(size = 9),  # Smaller legend title
    panel.background = element_blank(),
    panel.border = element_rect(color = "black", fill = NA, linewidth = 0.5),  # Adds the rectangle border
    panel.grid.major = element_line(color = "grey90", linewidth = 0.5),  # Adds horizontal grid lines
    panel.grid.minor = element_blank(),  # Removes minor grid lines if not needed
    panel.grid.major.x = element_blank(),  # Removes vertical grid lines
    axis.line = element_line(color = "black", linewidth = 0.5),  # Adds axis lines
    axis.text.x = element_text(size = 8),  # Change x axis text size
    axis.text.y = element_text(size = 8),  # Change y axis text size
    axis.title.x = element_text(size = 9), # Change x axis title size
    axis.title.y = element_text(size = 9),
    strip.text.x = element_text(size = 9),  # Adjust the size for horizontal facet labels
    strip.text.y = element_text(size = 9)   # Adjust the size for vertical facet labels# Change y axis title size
  ) +
  guides(color = guide_legend(direction = "horizontal"))
# Display the line plot with error bars, the red vertical line, and the "***" label
print(line_plot_emotions)
ggsave("plot_emotion.png", plot = line_plot_emotions, width = 6, height = 3, dpi = 300)






### plot with 3 exp ###
dat_exp <- dat_all %>% select(ID,Condition,Category,
                              Accuracy,Comprehensive,deq,
                              Motivated,Realistic,
                              Programming,STEM,Education)

# Named vector to map old names to new ones
exp_name_map  <- c(
  Accuracy = "Accuracy",
  Comprehensive = "Completeness",
  deq = "DEQ"
)
condition_name_map <- c(
  Open = "ED",
  `Guided free` = "FID",
  `Guided MC` = "SCD"
)

# Create a boxplot for each emotion, faceted by emotion
dat_exp_multi_long <- dat_exp %>%
  pivot_longer(cols = c(Accuracy, Comprehensive, deq),
               names_to = "exp",
               values_to = "value") %>%
  # Use the mappings to rename emotions and conditions
  mutate(exp = exp_name_map[exp],
         Condition = condition_name_map[Condition]) %>%
  # Set the factor level orders for 'exp' and 'Condition'
  mutate(exp = factor(exp, levels = c("Accuracy", "Completeness", "DEQ")),
         Condition = factor(Condition, levels = c("ED", "FID", "SCD")))


# Calculate mean and standard error (SE) for each emotion by Condition
exp_summary <- dat_exp_multi_long %>%
  group_by(exp, Condition) %>%
  summarize(
    Mean = mean(value),
    SE = sd(value) / sqrt(n())
  )

# Plot for Accuracy
line_plot_accuracy <- ggplot(subset(exp_summary, exp == "Accuracy"), aes(x = Condition, y = Mean, group = exp)) +
  geom_errorbar(aes(ymin = Mean - SE, ymax = Mean + SE, color = Condition), width = 0.2) +
  geom_point(aes(color = Condition), size = 3) +
  labs(y = "Mean and standard error", title = "Accuracy") +
  theme_minimal() +
  theme(
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    axis.title.x = element_blank(),
    legend.position = "none"
  ) +
  coord_cartesian(ylim = c(3.5, 4.3))

# Plot for Completeness
line_plot_completeness <- ggplot(subset(exp_summary, exp == "Completeness"), aes(x = Condition, y = Mean, group = exp)) +
  geom_errorbar(aes(ymin = Mean - SE, ymax = Mean + SE, color = Condition), width = 0.2) +
  geom_point(aes(color = Condition), size = 3) +
  labs(y = "Mean and standard error", title = "Completeness") +
  theme_minimal() +
  theme(
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    axis.title.x = element_blank(),
    legend.position = "none"
  ) +
  coord_cartesian(ylim = c(3.5, 4.3))

# Plot for DEQ
line_plot_deq <- ggplot(subset(exp_summary, exp == "DEQ"), aes(x = Condition, y = Mean, group = exp)) +
  geom_errorbar(aes(ymin = Mean - SE, ymax = Mean + SE, color = Condition), width = 0.2) +
  geom_point(aes(color = Condition), size = 3) +
  labs(y = "Mean and standard error", title = "DEQ") +
  
  # DEQ asterisks and lines
  geom_text(aes(x = 1.5, y = 4.5, label = "*"), color = "black", size = 4) +
  geom_segment(aes(x = 1, xend = 2, y = 4.5, yend = 4.5), color = "black", size = 0.5) +
  geom_text(aes(x = 2, y = 4.55, label = "*"), color = "black", size = 4) +
  geom_segment(aes(x = 1, xend = 3, y = 4.55, yend = 4.55), color = "black", size = 0.5) +
  
  theme_minimal() +
  theme(
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    axis.title.x = element_blank(),
    legend.position = "none"
  )

# Combine the plots side by side
final_plot <- line_plot_accuracy + line_plot_completeness + line_plot_deq

# Display the combined plot
print(final_plot)





######### multivariate analysis ----------
########### Experience ###################

# multivariate multiple regression
# Reshape the data to long format for plotting
dat_exp_multi <- dat_all %>% select(ID,Condition,Accuracy,Comprehensive,deq,
                                    Motivated,Realistic,
                                    Programming,STEM)
multi_lm_exp_all <- lm(cbind(Accuracy,Comprehensive,deq) ~ Condition+Motivated+Realistic+Programming+STEM, data = dat_exp_multi)
Anova(multi_lm_exp_all)
multi_lm_exp_CMRP <- update(multi_lm_exp_all, . ~ . -Programming)
anova(multi_lm_exp_all, multi_lm_exp_CMRP) # no diff
multi_lm_exp_CMR <- update(multi_lm_exp_all, . ~ . -Programming-STEM)
anova(multi_lm_exp_all, multi_lm_exp_CMR) # no diff
# -->cbind(Accuracy, Comprehensive, deq) ~ Condition + Motivated + Realistic
final_lm_multi_exp <- multi_lm_exp_CMR
Anova(final_lm_multi_exp)
summary(final_lm_multi_exp)
predict(final_lm_multi_exp, data.frame(Condition="Open",Motivated=4.3,Realistic=2.7))
predict(final_lm_multi_exp, data.frame(Condition="Guided free",Motivated=4.3,Realistic=2.7))
predict(final_lm_multi_exp, data.frame(Condition="Guided MC",Motivated=4.3,Realistic=2.7))


########### Emotions ###################

# multivariate multiple regression
# Reshape the data to long format for plotting
dat_emo_multi <- dat_all %>% select(ID,Condition,guilt,shame,au_pride,hu_pride,
                                    guilt_proneness,shame_proneness,au_pride_proneness,hu_pride_proneness,
                                    Motivated,Realistic,Education,Programming,STEM)
multi_lm_allemo_all <- lm(cbind(guilt,shame,au_pride,hu_pride) ~ Condition+guilt_proneness+shame_proneness+au_pride_proneness+hu_pride_proneness+
                         Motivated+Realistic+Education+Programming+STEM, data = dat_emo_multi)
Anova(multi_lm_allemo_all)
multi_lm_allemo_reduce <- update(multi_lm_allemo_all, . ~ . -Condition 
                                 -au_pride_proneness -hu_pride_proneness
                                 -Education -Programming -STEM)
anova(multi_lm_allemo_all, multi_lm_allemo_reduce) # no diff
# --> cbind(guilt, shame, au_pride, hu_pride) ~ guilt_proneness + shame_proneness + Motivated + Realistic
final_lm_multi_emo <- multi_lm_allemo_reduce
Anova(final_lm_multi_emo)
summary(final_lm_multi_emo)
predict(final_lm_multi_emo, data.frame(guilt_proneness=3.2,shame_proneness=2.9,Motivated=4.3,Realistic=2.7))


# try other combintation
multi_lm_shameguilt_all <- lm(cbind(guilt,shame) ~ Condition+guilt_proneness+shame_proneness+
                            Motivated+Realistic+Education+Programming+STEM, data = dat_emo_multi)
Anova(multi_lm_shameguilt_all)
multi_lm_pride_all <- lm(cbind(au_pride,hu_pride) ~ Condition+au_pride_proneness+hu_pride_proneness+
                           Motivated+Realistic+Education+Programming+STEM, data = dat_emo_multi)
Anova(multi_lm_pride_all)
multi_lm_shameguiltpride_all <- lm(cbind(guilt,shame,au_pride) ~ guilt_proneness+shame_proneness+au_pride_proneness+
                           Motivated+Realistic+Education+Programming+STEM, data = dat_emo_multi)
Anova(multi_lm_shameguiltpride_all)



########### DV IV preliminary check ###################
summary(lm(Accuracy ~ Condition, data = dat_all)) #no
summary(lm(Comprehensive ~ Condition, data = dat_all)) #Guided MC
summary(lm(deq ~ Condition, data = dat_all)) #no
summary(lm(shame ~ Condition, data = dat_all)) #no
summary(lm(guilt ~ Condition, data = dat_all)) #no
summary(lm(au_pride ~ Condition, data = dat_all)) #Open
summary(lm(hu_pride ~ Condition, data = dat_all)) #no



########### ACC/COMP ###################
#### Correlation check
# ACC ~ motivation
summary(lm(Accuracy ~ Motivated, data = dat_all)) #no
summary(lm(Accuracy ~ Realistic, data = dat_all)) #yes
# ACC ~ other
summary(lm(Accuracy ~ factor(Gender), data = dat_all)) #no
summary(lm(Accuracy ~ factor(Age), data = dat_all)) #no
summary(lm(Accuracy ~ factor(Education), data = dat_all)) #no
summary(lm(Accuracy ~ factor(STEM), data = dat_all)) #no
summary(lm(Accuracy ~ factor(Programming), data = dat_all)) #no
# COMP ~ motivation
summary(lm(Comprehensive ~ Motivated, data = dat_all)) #yes
summary(lm(Comprehensive ~ Realistic, data = dat_all)) #yes
# COMP ~ other
summary(lm(Comprehensive ~ factor(Gender), data = dat_all)) #no
summary(lm(Comprehensive ~ factor(Age), data = dat_all)) #youngest
ggplot(data=dat_all, aes(x=Age, y=Comprehensive)) +
  geom_bar(stat="identity")
summary(lm(Comprehensive ~ factor(Education), data = dat_all)) #PhD very little
summary(lm(Comprehensive ~ factor(STEM), data = dat_all)) #no
summary(lm(Comprehensive ~ factor(Programming), data = dat_all)) #no
# DEQ ~ motivation
summary(lm(deq ~ Motivated, data = dat_all)) #yes
summary(lm(deq ~ Realistic, data = dat_all)) #no
# DEQ ~ other
summary(lm(deq ~ factor(Gender), data = dat_all)) #no
summary(lm(deq ~ factor(Age), data = dat_all)) #no
summary(lm(deq ~ factor(Education), data = dat_all)) #PhD master
summary(lm(deq ~ factor(STEM), data = dat_all)) #no
summary(lm(deq ~ factor(Programming), data = dat_all)) #no
# shame ~ motivation
summary(lm(shame ~ Motivated, data = dat_all)) #no
summary(lm(shame ~ Realistic, data = dat_all)) #a little
# shame ~ other
summary(lm(shame ~ factor(Gender), data = dat_all)) #no
summary(lm(shame ~ factor(Age), data = dat_all)) #no
summary(lm(shame ~ factor(Education), data = dat_all)) #high school
summary(lm(shame ~ factor(STEM), data = dat_all)) #no
summary(lm(shame ~ factor(Programming), data = dat_all)) #Novice
# guilt ~ motivation
summary(lm(guilt ~ Motivated, data = dat_all)) #no
summary(lm(guilt ~ Realistic, data = dat_all)) #no
# guilt ~ other
summary(lm(guilt ~ factor(Gender), data = dat_all)) #no
summary(lm(guilt ~ factor(Age), data = dat_all)) #no
summary(lm(guilt ~ factor(Education), data = dat_all)) #high school
summary(lm(guilt ~ factor(STEM), data = dat_all)) #no
summary(lm(guilt ~ factor(Programming), data = dat_all)) #Novice
# au_pride ~ motivation
summary(lm(au_pride ~ Motivated, data = dat_all)) #yes
summary(lm(au_pride ~ Realistic, data = dat_all)) #no
# au_pride ~ other
summary(lm(au_pride ~ factor(Gender), data = dat_all)) #no
summary(lm(au_pride ~ factor(Age), data = dat_all)) #no
summary(lm(au_pride ~ factor(Education), data = dat_all)) #no
summary(lm(au_pride ~ factor(STEM), data = dat_all)) #no
summary(lm(au_pride ~ factor(Programming), data = dat_all)) #No experience a little
# hu_pride ~ motivation
summary(lm(hu_pride ~ Motivated, data = dat_all)) #yes
summary(lm(hu_pride ~ Realistic, data = dat_all)) #no
# hu_pride ~ other
summary(lm(hu_pride ~ factor(Gender), data = dat_all)) #no
summary(lm(hu_pride ~ factor(Age), data = dat_all)) #very little
summary(lm(hu_pride ~ factor(Education), data = dat_all)) #no
summary(lm(hu_pride ~ factor(STEM), data = dat_all)) #yes
summary(lm(hu_pride ~ factor(Programming), data = dat_all)) #No experience yes

#### Correlation check
# Emotions ~ gender (result: nothing)
summary(lm(guilt ~ factor(Gender), data = dat_all))
summary(lm(shame ~ factor(Gender), data = dat_all))
summary(lm(au_pride ~ factor(Gender), data = dat_all))
summary(lm(hu_pride ~ factor(Gender), data = dat_all))
# Emotions ~ Age (result: a little for pride)
summary(lm(guilt ~ factor(Age), data = dat_all))
summary(lm(shame ~ factor(Age), data = dat_all))
summary(lm(au_pride ~ factor(Age), data = dat_all))
summary(lm(hu_pride ~ factor(Age), data = dat_all))
# Emotions ~ Education (result: high school guilt shame)
summary(lm(guilt ~ factor(Education), data = dat_all))
summary(lm(shame ~ factor(Education), data = dat_all))
summary(lm(au_pride ~ factor(Education), data = dat_all))
summary(lm(hu_pride ~ factor(Education), data = dat_all))
# Emotions ~ STEM (result: hu_pride)
summary(lm(guilt ~ factor(STEM), data = dat_all))
summary(lm(shame ~ factor(STEM), data = dat_all))
summary(lm(au_pride ~ factor(STEM), data = dat_all))
summary(lm(hu_pride ~ factor(STEM), data = dat_all))
# Emotions ~ Programming (result: yes, differ per emotion)
summary(lm(guilt ~ factor(Programming), data = dat_all))
summary(lm(shame ~ factor(Programming), data = dat_all))
summary(lm(au_pride ~ factor(Programming), data = dat_all))
summary(lm(hu_pride ~ factor(Programming), data = dat_all))
# Emotions ~ proness (result: except hu_pride)
summary(lm(guilt ~ guilt_proneness, data = dat_all))
summary(lm(shame ~ shame_proneness, data = dat_all))
summary(lm(au_pride ~ au_pride_proneness, data = dat_all))
summary(lm(hu_pride ~ hu_pride_proneness, data = dat_all))

# correlation between variables
summary(lm(Motivated ~ Realistic, data = dat_all)) #yes
summary(lm(Accuracy ~ Comprehensive, data = dat_all)) #yes
dat_rcorr_exp <- dat_all %>% select(Accuracy,Comprehensive,deq)
rcorr(as.matrix(dat_rcorr)) #acc, comp, deq highly related

dat_rcorr_emo <- dat_all %>% select(shame,guilt,au_pride,hu_pride,deq)
rcorr(as.matrix(dat_rcorr_emo)) 
#shame-guilt,shame-au_pride,au_pride-hu_pride,
#deq-au_pride,deq-hu_pride

# plot exploration
# acc_comp_deq + condition
dat_acc_comp_deq <- dat_all %>% select(ID,Condition,Accuracy,Comprehensive,deq)
dat_acc_comp_deq_long <- dat_acc_comp_deq %>%
  pivot_longer(cols = c(Accuracy,Comprehensive,deq),
               names_to = "measure",
               values_to = "score")
dat_acc_comp_deq.summary <- summarySE(dat_acc_comp_deq_long, measurevar="score", groupvars=c("Condition","measure"))
ggplot(dat_acc_comp_deq.summary, aes(x=measure,y=score,colour = Condition, group = Condition)) +
  geom_errorbar(aes(ymin=score-se, ymax=score+se), width=.2) +
  geom_line() +
  theme_bw() +
  geom_point(size = 5)
summary(lmer(score ~ Condition+measure+(1|ID), data = dat_acc_comp_deq_long))

# stacked barplot
ggplot(dat_acc_comp_deq) + 
  geom_bar(aes(x = Condition, fill = factor(Accuracy)), position = 'fill')+
  ylab('Proportion')+
  xlab('Condition')+
  coord_flip()
dat_acc_comp <- dat_all %>% select(ID,Condition,Accuracy,Comprehensive)
dat_acc_complong <- dat_acc_comp_deq %>%
  pivot_longer(cols = c(Accuracy,Comprehensive),
               names_to = "measure",
               values_to = "score")
ggplot(dat_acc_complong, aes(x=measure)) +
  geom_bar(aes(fill=factor(score)))+
  facet_wrap(~Condition)

#deq distribution + Cond
ggplot(dat_all, aes(x=deq, colour=Condition)) + geom_density()+
  xlim(1, 7)+xlab("DEQ")

# different emo + condition
dat_emo_multi <- dat_all %>% select(ID,Condition,shame,guilt,au_pride,hu_pride)
dat_emo_multi_long <- dat_emo_multi %>%
  pivot_longer(cols = c(shame,guilt,au_pride,hu_pride),
               names_to = "measure",
               values_to = "score")
dat_emo.summary <- summarySE(dat_emo_multi_long, measurevar="score", groupvars=c("Condition","measure"))
ggplot(dat_emo.summary, aes(x=measure,y=score,colour = Condition, group = Condition)) +
  geom_errorbar(aes(ymin=score-se, ymax=score+se), width=.2) +
  geom_line() +
  theme_bw() +
  geom_point(size = 5)