# -*- coding: utf-8 -*-
"""
Created on Mon Feb 26 16:35:23 2024

@author: pychen
"""

import os
import pandas as pd
import itertools
from collections import defaultdict

# Set the working directory to the directory containing the script
script_directory = os.path.dirname(os.path.abspath(__file__))
os.chdir(script_directory)

#%%
# Load your CSV data into a DataFrame
data = pd.read_csv("open-coded-combination.csv", usecols=["Big category 0", 
                                                          "Big category 1", 
                                                          "Big category 2",
                                                          "Big category 3",
                                                          "Big category 4"])
# Replace any NaN values with "NA" (or any other label you prefer)
data = data.fillna("NA")
data = data.apply(lambda x: x.str.split(', '))
data = data.rename(columns={'Big category 0': 'col0',
                            'Big category 1': 'col1', 
                            'Big category 2': 'col2',
                            'Big category 3': 'col3',
                            'Big category 4': 'col4'})
#%%
# Define a function to generate combinations for consecutive pairs of columns
def generate_combinations(row, columns):
    combinations_list = []
    for i in range(len(columns) - 1):
        combinations_list.extend(list(itertools.product(row[columns[i]], row[columns[i+1]])))
    return combinations_list

# Initialize lists for each pair of combinations
combinations_col0_col1 = []
combinations_col1_col2 = []
combinations_col2_col3 = []
combinations_col3_col4 = []

# Apply the function to each row and collect combinations for each pair of columns
for index, row in data.iterrows():
    combinations_col0_col1.extend(generate_combinations(row, ['col0', 'col1']))
    combinations_col1_col2.extend(generate_combinations(row, ['col1', 'col2']))
    combinations_col2_col3.extend(generate_combinations(row, ['col2', 'col3']))
    combinations_col3_col4.extend(generate_combinations(row, ['col3', 'col4']))

#%%
# Convert lists to DataFrames
df_Q0Q1 = pd.DataFrame(combinations_col0_col1, columns=['preceding', 'following'])
df_Q1Q2 = pd.DataFrame(combinations_col1_col2, columns=['preceding', 'following'])
df_Q2Q3 = pd.DataFrame(combinations_col2_col3, columns=['preceding', 'following'])
df_Q3Q4 = pd.DataFrame(combinations_col3_col4, columns=['preceding', 'following'])

#%% what to ask once excuse is said? (fix excuse)

# Initialize a defaultdict to store probabilities
probabilities = defaultdict(lambda: defaultdict(int))

# Count occurrences of each combination for each first column element
counts = defaultdict(int)
for index, row in df_Q0Q1.iterrows():
    first_col = row['preceding']
    counts[first_col] += 1
    probabilities[first_col][row['following']] += 1

# Calculate probabilities for each first column element
for first_col, count in counts.items():
    for second_col, occurrence in probabilities[first_col].items():
        probabilities[first_col][second_col] /= count

# Convert probabilities to DataFrame
prob_data = [(first_col, second_col, prob) for first_col, second_cols in probabilities.items() for second_col, prob in second_cols.items()]
prob_df_fixQ0_predictQ1 = pd.DataFrame(prob_data, columns=['first_col', 'second_col', 'probability'])

#%% what to ask if want to get information?

# Initialize a defaultdict to store probabilities
probabilities = defaultdict(lambda: defaultdict(int))

# Count occurrences of each combination for each second column element
counts = defaultdict(int)
for index, row in df_Q0Q1.iterrows():
    second_col = row['following']
    counts[second_col] += 1
    probabilities[second_col][row['preceding']] += 1

# Calculate probabilities for each second column element
for second_col, count in counts.items():
    for first_col, occurrence in probabilities[second_col].items():
        probabilities[second_col][first_col] /= count

# Convert probabilities to DataFrame
prob_data = [(second_col, first_col, prob) for second_col, first_cols in probabilities.items() for first_col, prob in first_cols.items()]
prob_df_fixQ1_precededby = pd.DataFrame(prob_data, columns=['second_col', 'first_col', 'probability'])


#%% what do we get after emotions?

# Initialize a defaultdict to store probabilities
probabilities = defaultdict(lambda: defaultdict(int))

# Count occurrences of each combination for each first column element
counts = defaultdict(int)
for index, row in df_Q3Q4.iterrows():
    first_col = row['preceding']
    counts[first_col] += 1
    probabilities[first_col][row['following']] += 1

# Calculate probabilities for each first column element
for first_col, count in counts.items():
    for second_col, occurrence in probabilities[first_col].items():
        probabilities[first_col][second_col] /= count

# Convert probabilities to DataFrame
prob_data = [(first_col, second_col, prob) for first_col, second_cols in probabilities.items() for second_col, prob in second_cols.items()]
prob_df_fixQ3_predictQ4 = pd.DataFrame(prob_data, columns=['first_col', 'second_col', 'probability'])



#%% What do we get in Q2, given Q1?

# Initialize a defaultdict to store probabilities
probabilities = defaultdict(lambda: defaultdict(int))

# Count occurrences of each combination for each first column element
counts = defaultdict(int)
for index, row in df_Q1Q2.iterrows():
    first_col = row['preceding']
    counts[first_col] += 1
    probabilities[first_col][row['following']] += 1

# Calculate probabilities for each first column element
for first_col, count in counts.items():
    for second_col, occurrence in probabilities[first_col].items():
        probabilities[first_col][second_col] /= count

# Convert probabilities to DataFrame
prob_data = [(first_col, second_col, prob) for first_col, second_cols in probabilities.items() for second_col, prob in second_cols.items()]
prob_df_fixQ1_predictQ2 = pd.DataFrame(prob_data, columns=['first_col', 'second_col', 'probability'])


#%% what to ask if want to get information X in Q2?

# Initialize a defaultdict to store probabilities
probabilities = defaultdict(lambda: defaultdict(int))

# Count occurrences of each combination for each second column element
counts = defaultdict(int)
for index, row in df_Q1Q2.iterrows():
    second_col = row['following']
    counts[second_col] += 1
    probabilities[second_col][row['preceding']] += 1

# Calculate probabilities for each second column element
for second_col, count in counts.items():
    for first_col, occurrence in probabilities[second_col].items():
        probabilities[second_col][first_col] /= count

# Convert probabilities to DataFrame
prob_data = [(second_col, first_col, prob) for second_col, first_cols in probabilities.items() for first_col, prob in first_cols.items()]
prob_df_fixQ2_precededby = pd.DataFrame(prob_data, columns=['second_col', 'first_col', 'probability'])


#%% below old code ignore

occurrences_Q0Q1 = df_Q0Q1.groupby(['preceding', 'following']).size().reset_index(name='occurrences')
# Calculate occurrences for df_Q1Q2 DataFrame
occurrences_Q1Q2 = df_Q1Q2.groupby(['preceding', 'following']).size().reset_index(name='occurrences')
# Calculate occurrences for df_Q2Q3 DataFrame
occurrences_Q2Q3 = df_Q2Q3.groupby(['preceding', 'following']).size().reset_index(name='occurrences')
# Calculate occurrences for df_Q3Q4 DataFrame
occurrences_Q3Q4 = df_Q3Q4.groupby(['preceding', 'following']).size().reset_index(name='occurrences')

total_occurrences_Q0Q1 = occurrences_Q0Q1['occurrences'].sum()
# Calculate total occurrences for occurrences_Q1Q2 DataFrame
total_occurrences_Q1Q2 = occurrences_Q1Q2['occurrences'].sum()
# Calculate total occurrences for occurrences_Q2Q3 DataFrame
total_occurrences_Q2Q3 = occurrences_Q2Q3['occurrences'].sum()
# Calculate total occurrences for occurrences_Q3Q4 DataFrame
total_occurrences_Q3Q4 = occurrences_Q3Q4['occurrences'].sum()

occurrences_Q0Q1['percentage'] = (occurrences_Q0Q1['occurrences'] / total_occurrences_Q0Q1)
# Add a "percentage" column to df_Q1Q2 DataFrame
occurrences_Q1Q2['percentage'] = (occurrences_Q1Q2['occurrences'] / total_occurrences_Q1Q2)
# Add a "percentage" column to df_Q2Q3 DataFrame
occurrences_Q2Q3['percentage'] = (occurrences_Q2Q3['occurrences'] / total_occurrences_Q2Q3) 
# Add a "percentage" column to df_Q3Q4 DataFrame
occurrences_Q3Q4['percentage'] = (occurrences_Q3Q4['occurrences'] / total_occurrences_Q3Q4)


